import { PlatformAccessory, CharacteristicValue } from 'homebridge';
import { DaikinApi } from './daikinapi';
import { DaikinOnePlusPlatform } from './platform';
/**
 * Thermostat
 * Exposes thermostat related characteristics for the Daikin One+ thermostat.
 */
export declare class DaikinOnePlusThermostat {
    private readonly platform;
    private readonly accessory;
    private readonly deviceId;
    private readonly daikinApi;
    private service;
    constructor(platform: DaikinOnePlusPlatform, accessory: PlatformAccessory, deviceId: string, daikinApi: DaikinApi);
    updateValues(): void;
    /**
     * Handle requests to get the current value of the "Current Heating Cooling State" characteristic
     */
    handleCurrentHeatingCoolingStateGet(): CharacteristicValue;
    /**
     * Handle requests to get the current value of the "Target Heating Cooling State" characteristic
     */
    handleTargetHeatingCoolingStateGet(): CharacteristicValue;
    /**
     * Handle requests to get the current value of the "Current Temperature" characteristic
     */
    handleCurrentTemperatureGet(): CharacteristicValue;
    /**
     * Handle requests to get the current value of the "Target Temperature" characteristic
     */
    handleTargetTemperatureGet(): CharacteristicValue;
    handleHeatingThresholdTemperatureGet(): CharacteristicValue;
    handleCoolingThresholdTemperatureGet(): CharacteristicValue;
    /**
     * Handle requests to get the current value of the "Temperature Display Units" characteristic
     */
    handleTemperatureDisplayUnitsGet(): CharacteristicValue;
    /**
     * Handle requests to get the current value of the "Current Relative Humidity" characteristic
     */
    handleCurrentHumidityGet(): CharacteristicValue;
    /**
     * Handle requests to get the current value of the "Target Temperature" characteristic
     */
    handleTargetHumidityGet(): CharacteristicValue;
    /**
     * Handle requests to set the "Target Heating Cooling State" characteristic
     */
    handleTargetHeatingCoolingStateSet(value: CharacteristicValue): Promise<void>;
    /**
     * Handle requests to set the "Target Temperature" characteristic
     */
    handleTargetTemperatureSet(value: CharacteristicValue): Promise<void>;
    /**
     * Handle requests to set the "Cooling Threshold Temperature" characteristic
     */
    handleCoolingThresholdTemperatureSet(value: CharacteristicValue): Promise<void>;
    /**
     * Handle requests to set the "Heating Threshold Temperature" characteristic
     */
    handleHeatingThresholdTemperatureSet(value: CharacteristicValue): Promise<void>;
    /**
     * Handle requests to set the "Temperature Display Units" characteristic
     */
    handleTemperatureDisplayUnitsSet(value: CharacteristicValue): Promise<void>;
    /**
     * Handle requests to set the "Target Humidity" characteristic
     */
    handleTargetHumiditySet(value: CharacteristicValue): Promise<void>;
}
//# sourceMappingURL=platformThermostat.d.ts.map